@@ -23,9 +23,6 @@ class GnomeScreenshotWrapper(CBackend):
     name = "gnome-screenshot"
     is_subprocess = True
 
-    def __init__(self):
-        pass
-
     def grab(self, bbox=None):
         im = read_prog_img([PROGRAM, "-f"])
         if bbox:
